##  Step 4: Complete a Processor Run to Import Data
Follow these steps:
  1. On the page of the processor that you created, enter the following code in the input field on the left:

```
{
  "processors": [
      {
        "processorType": "inboundDocument",
        "processorName": "applicationResourceMapper",
        "processorDescription": "Processor to link applications to their relevant resources",
        "identifier": {
            "internal": "${content.id}"
        },
        "run": 0,
        "updates": [
            {
              "key": {
                  "expr": "name"
              },
              "values": [
                  {
                    "expr": "${content.data.name}"
                  }
              ]
            },
            {
              "key": {
                  "expr": "url"
              },
              "values": [
                  {
                    "expr": "${content.data.url}"
                  }
              ]
            }
        ],
        "enabled": true
      }
  ],
  "variables": {}
}
```



  2. Under Input, enter the following code. In the content field, add an array of objects in JSON format that you retrieved in the previous step. Each object should contain the type and id of the fact sheet and the links to be added. In the example, we import two links to application fact sheets.

```
{
  "connectorType": "leanix",
  "connectorId": "leanix-pandasCSV",
  "connectorVersion": "1.0.0",
  "lxVersion": "1.0.0",
  "description": "LDIF Generated by PANDAS CSV data",
  "processingDirection": "inbound",
  "processingMode": "partial",
  "customFields": {},
  "content": [
      {
        "type": "Application",
        "id": "28fe4aa2-6e46-41a1-....-72afb3acf256",
        "data": {
            "name": "Technical documentation",
            "url": "https://docs.example.net/"
        }
      },
      {
        "type": "Application",
        "id": "2efa37b5-18aa-48d8-....-1328c0d856d7",
        "data": {
            "name": "Vendor's website",
            "url": "https://www.example-vendor.net/"
        }
      }
  ]
}
```



  3. Click Save.
  4. To test the processor, click Test run. Once the run is completed, check the output log for possible errors. If the run is successful, proceed to the next step.
  5. To initiate the import process, click Run.


The links with associated names are added as resources to the specified application fact sheets.
To verify that the import was successful, navigate to the Resources tab of a specific fact sheet. You can also run a GraphQL query in the [GraphiQL Tool](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a6d497a4410149a8bffcc34da11b9__graphiql_tool) to retrieve resources for a specific fact sheet.
Example query:

```
{
  factSheet(id: "{id}") {
    id
    name
    documents {
      edges {
        node {
          origin
          url
          name
        }
      }
    }
  }
}
```



